@@ -2,13 +2,7 @@ from django.conf import settings
 from django.db import models
 
 
-try:
-    UserModel = settings.FCM_USER_MODEL
-except AttributeError:
-    UserModel = settings.AUTH_USER_MODEL
-
-
-class FCMDevice(models.Model):
+class FCMDeviceBase(models.Model):
     class Platforms(models.TextChoices):
         ANDROID = "android", "Android"
         IOS = "ios", "iOS"
@@ -16,7 +10,7 @@ class FCMDevice(models.Model):
         UNKNOWN = "unknown", "Unknown"
 
     registration_id = models.CharField(unique=True, max_length=255)
-    user = models.ForeignKey(UserModel, on_delete=models.CASCADE, null=False, blank=False)
+    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, null=False, blank=False)
     topics = models.ManyToManyField("firebase_push.FCMTopic", related_name="devices")
     platform = models.CharField(
         choices=Platforms.choices, max_length=8, default=Platforms.UNKNOWN, null=False, blank=False
@@ -34,3 +28,6 @@ class FCMDevice(models.Model):
             ", ".join([topic.name for topic in self.topics.all()]),
             self.app_version,
         )
+
+    class Meta:
+        abstract = True
