@@ -3,12 +3,6 @@ from django.db import models
 from django.utils.translation import gettext_lazy as _
 
 
-try:
-    UserModel = settings.FCM_USER_MODEL
-except AttributeError:
-    UserModel = settings.AUTH_USER_MODEL
-
-
 class FCMHistoryBase(models.Model):
     class Status(models.TextChoices):
         PENDING = "pending", _("Pending")
@@ -17,8 +11,8 @@ class FCMHistoryBase(models.Model):
 
     message_data = models.JSONField()
     message_id = models.UUIDField()
-    device = models.ForeignKey("firebase_push.FCMDevice", on_delete=models.SET_NULL, blank=True, null=True)
-    user = models.ForeignKey(UserModel, on_delete=models.CASCADE, null=False, blank=False)
+    device = models.ForeignKey(settings.FCM_DEVICE_MODEL, on_delete=models.SET_NULL, blank=True, null=True)
+    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, null=False, blank=False)
     topic = models.ForeignKey("firebase_push.FCMTopic", on_delete=models.SET_NULL, blank=True, null=True)
     status = models.CharField(choices=Status.choices, default=Status.PENDING, max_length=8, blank=False, null=False)
     error_message = models.TextField(default="", blank=True, null=False)
